classdef initialization
    %UNTITLED2 Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
    end
    
    methods (Static)
        
        function [speciesProperties] = get_speciesProperties(Params)
            % This function is in order to import speciesProperties information from speciesProperties.csv file
            % Input filename is a character string, e.g.='speciesProperties.csv';
            % Output speciesProperties is cell array of subCellArray(1)Name (2)mass
            
            % Get fileID
            fid = fopen(Params);
            % Get format for every species information field(1)(2), hier every format is character string
            format='%s%s';
            % Use komma to be the delimiter
            delimiter=',';
            % Seperate every speciesProperties information info field, save into cell array speciesProperties
            speciesProperties=textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
        end
        
        
        function [species] = get_species(Params)
            % This function is in order to import species information from species.csv file
            % Input filename is a character string, e.g.='species.csv';
            % Output species is cell array of subCellArray(1)Name (2)Energy (3)Charge
            % (4)Includes (5)Degeneracy
            
            % Get fileID
            fid=fopen(Params.inputFiles.species);
            % Get format for every species information field(1)(2)(3)(4)(5), hier every format is character string
            format='%s%s%s%s%s';
            % Use komma to be the delimiter
            delimiter=',';
            % Seperate every species information info field, save into cell array species
            species=textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
            
            % erase the comment row "%%" and note row "##" in the "species" input csv
            a = length(species{1});
            b = 1:a;
            c_1 = find(contains(species{1},"##"));
            c_2 = find(contains(species{1},"%%"));
            d=setdiff(b,c_1);
            d=setdiff(d,c_2);
            for i=1:5
            species{i}=species{i}(d);
            end
            
        end
        
        function [reactions] = get_reactions_previous(Params)
            % This function is in order to import reactions information from reactions.csv file
            % Input filename is a character string, e.g.='reactions.csv';
            % Output species is cell array of subCellArray(1)Name (2)Reactions (3)Type
            % (4)FuncOrLut (5)DB: Detailed Balancing
            
            % Get fileID
            fid=fopen(Params.inputFiles.reactions_previous);
            % Get format for every species information field(1)(2)(3)(4)(5), hier every format is character string
            format='%s%s%s%s%s%s';
            % Use komma to be the delimiter
            delimiter=',';
            % Seperate every reactions information info field, save into cell array reactions
            reactions=textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
            
            % erase the comment row "%%" and note row "##" in the "reactions" input csv
            a = length(reactions{1});
            b = 1:a;
            c_1 = find(contains(reactions{1},"##"));
            c_2 = find(contains(reactions{1},"%%"));
            d=setdiff(b,c_1);
            d=setdiff(d,c_2);
            % erase the reactions, whose rate coefficient are not yet found
            c_3 = find(contains(reactions{4},"--------------------"));
            d=setdiff(d,c_3);
            for i=1:6
            reactions{i}=reactions{i}(d);
            end
            
        end
        
        function [reactions] = get_reactions(Params)
            % This function is in order to import reactions information from reactions.csv file
            % Input filename is a character string, e.g.='reactions.csv';
            % Output species is cell array of subCellArray(1)Name (2)Reactions (3)Type
            % (4)FuncOrLut (5)DB: Detailed Balancing
            
            % Get fileID
            fid=fopen(Params.inputFiles.reactions);
            % Get format for every species information field(1)(2)(3)(4)(5), hier every format is character string
            format='%s%s%s%s%s%s';
            % Use komma to be the delimiter
            delimiter=',';
            % Seperate every reactions information info field, save into cell array reactions
            reactions=textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
            
            % erase the comment row "%%" and note row "##" in the "reactions" input csv
            a = length(reactions{1});
            b = 1:a;
            c_1 = find(contains(reactions{1},"##"));
            c_2 = find(contains(reactions{1},"%%"));
            d=setdiff(b,c_1);
            d=setdiff(d,c_2);
            % erase the reactions, whose rate coefficient are not yet found
            c_3 = find(contains(reactions{4},"--------------------"));
            d=setdiff(d,c_3);
            for i=1:6
            reactions{i}=reactions{i}(d);
            end
            
        end
        
        
        function [reactions] = get_reactions_list(Params)
            % This function is in order to import reactions information from reactions.csv file
            % Input filename is a character string, e.g.='reactions.csv';
            % Output species is cell array of subCellArray(1)Name (2)Reactions (3)Type
            % (4)FuncOrLut (5)DB: Detailed Balancing
            
            % Get fileID
            fid=fopen(Params.inputFiles.reactions_previous);
            % Get format for every species information field(1)(2)(3)(4)(5), hier every format is character string
            format='%s%s%s%s%s%s';
            % Use komma to be the delimiter
            delimiter=',';
            % Seperate every reactions information info field, save into cell array reactions
            reactions=textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
            
            % erase the comment row "%%" and note row "##" in the "reactions" input csv
            a = length(reactions{1});
            b = 1:a;
            c_1 = find(contains(reactions{1},"##"));
            c_2 = find(contains(reactions{1},"%%"));
            d=setdiff(b,c_1);
            d=setdiff(d,c_2);
%             % erase the reactions, whose rate coefficient are not yet found
%             c_3 = find(contains(reactions{4},"--------------------"));
%             d=setdiff(d,c_3);
            for i=1:6
            reactions{i}=reactions{i}(d);
            end
            
        end
        
        
        function [NWR] = get_neutralWallReactions(Params)
            % This function is in order to import neutralWallReactions information from neutralWallReactions.csv file
            % Input filename is a character string, e.g.='neutralWallReactions.csv';
            % Output species is cell array of subCellArray(1)Name (2)ionWallReactions (3)FunctionType (4) wall reaction probability
            
            % Get fileID
            fid=fopen(Params.inputFiles.neutralWallReactions);
            % Get format for every species information field(1)(2)(3)(4), hier every format is character string
            format='%s%s%s%s';
            % Use komma to be the delimiter
            delimiter=',';
            % Seperate every reactions information info field, save into cell array reactions
            NWR=textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
        end
        
        function [IWR] = get_ionWallReactions(Params)
            % This function is in order to import ionWallReactions information from ionWallReactions.csv file
            % Input filename is a character string, e.g.='ionWallReactions.csv';
            % Output species is cell array of subCellArray(1)Name (2)ionWallReactions (3)FunctionType
            
            % Get fileID
            fid=fopen(Params.inputFiles.ionWallReactions);
            % Get format for every species information field(1)(2)(3), hier every format is character string
            format='%s%s%s';
            % Use komma to be the delimiter
            delimiter=',';
            % Seperate every reactions information info field, save into cell array reactions
            IWR=textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
        end
        
        function [initialValues] = get_initialValues(Params)
            % This function is in order to import initialValues information from initialValues.csv file
            % Input filename is a character string, e.g.='initialValues.csv';
            % Output species is cell array of subCellArray(1)Name (2)initialValues (3)Unit
            
            % Get fileID
            fid=fopen(Params.inputFiles.initialValues);
            % Get format for every species information field(1)(2)(3), hier every format is character string
            format='%s%s%s';
            % Use komma to be the delimiter
            delimiter = ',';
            % Seperate every initialValues information info field, save into cell array initialValues
            initialValues = textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
            
            % erase the comment row "%%" and note row "##" in the "species" input csv
            a = length(initialValues{1});
            b = 1:a;
            c_1 = find(contains(initialValues{1},"##"));
            c_2 = find(contains(initialValues{1},"%%"));
            d=setdiff(b,c_1);
            d=setdiff(d,c_2);
            for i=1:3
            initialValues{i}=initialValues{i}(d);
            end
        end
        
        function [ECR] = get_elasticCollisionReactions_previous(Params)
            % This function is in order to import elasticCollisionReactions information from elasticCollisionReactions.csv file
            % Input filename is a character string, e.g.='elasticCollisionReactions.csv';
            % Output species is cell array of subCellArray(1)Name (2)elasticCollisionReactions (3)FunctionType (4)FuncOrLut
            
            % Get fileID
            fid = fopen(Params.inputFiles.elasticCollision_previous);
            % Get format for every species information field(1)(2)(3)(4), hier every format is character string
            format = '%s%s%s%s%s';
            % Use komma to be the delimiter
            delimiter = ',';
            % Seperate every reactions information info field, save into cell array reactions
            ECR = textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
        end
        
        function [ECR] = get_elasticCollisionReactions(Params)
            % This function is in order to import elasticCollisionReactions information from elasticCollisionReactions.csv file
            % Input filename is a character string, e.g.='elasticCollisionReactions.csv';
            % Output species is cell array of subCellArray(1)Name (2)elasticCollisionReactions (3)FunctionType (4)FuncOrLut
            
            % Get fileID
            fid = fopen(Params.inputFiles.elasticCollision);
            % Get format for every species information field(1)(2)(3)(4), hier every format is character string
            format = '%s%s%s%s%s';
            % Use komma to be the delimiter
            delimiter = ',';
            % Seperate every reactions information info field, save into cell array reactions
            ECR = textscan(fid,format,'Delimiter', delimiter,'HeaderLines',1);
            % close file
            fclose(fid);
        end
        
    end
    
end

