clear all; close all; clc,

addpath('0_data_Nayak')

[x1,Hestar] = importfile('0_data_Nayak/meas_fig7_He_star.txt');
x1_ave = x1+0.8;

mean_He_star  = mean(Hestar);
ave_He_star = trapz(x1_ave,Hestar)/(max(x1_ave));

steat_res = load('Output/He/speciesDensities.mat');
dens = steat_res.n_density(end,:);

[t1,Hestar_t] = importfile('0_data_Nayak/meas_fig8_He_star.txt');
[t2,He2star_t] = importfile('0_data_Nayak/meas_fig8_He2_star.txt');

spp = SimParametersP('InputFolder/InputFile_pulsed.txt');

hestar_sim_sp = dens(1,spp.SpeciesIndex('He*1'))*ones(size(x1_ave));
hestar_ave = ave_He_star*ones(size(x1_ave));

[t_pow,pow] = importpower(spp.Params.pulse.lut);


pon = load('Output/HePulsed/Pulseon_10.mat');
poff = load('Output/HePulsed/Pulseoff_10.mat');

hestar_sol_index = spp.SpeciesIndex('He*1')+1;
he2star_sol_index = spp.SpeciesIndex('He2*')+1;

timea_sim = pon.sol(:,1);
timeb_sim = poff.sol(:,1)+pon.sol(end,1);

time_sim = [timea_sim; timeb_sim];
hestar_sim = [pon.sol(:,hestar_sol_index); poff.sol(:,hestar_sol_index)];
he2star_sim = [pon.sol(:,he2star_sol_index); poff.sol(:,he2star_sol_index)];
stomus = 1e6;

density_range_file = load('calculationOfMineForBenchmarking.mat', 'mine_n_list');
power_range_file = load('calculationOfMineForBenchmarking.mat', 'mine_reset_power');

power_range = power_range_file.mine_reset_power;

hestar_range = [];
for ii=1:1:length(power_range) 
    dummy = density_range_file.mine_n_list{1,ii};
    hestar_range(ii) = dummy(end,2);
end
aa = 15;
bb = hestar_ave(1,1);




figure(1)
scale = 1e18;
m1 = plot(aa,max(Hestar)./scale,'s','Color','r','MarkerSize',8)
% set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
m2 = plot(aa,bb./scale,'s','Color','r','MarkerSize',8)
set(m2, 'markerfacecolor', get(m2, 'color'));
hold on
plot(power_range,hestar_range./scale,'k-','LineWidth',2)
legend({'Meas. (Peak)', 'Meas. (Spat-ave.)', 'Sim.'},...
    'Location','NorthEast')
set(gca,'FontSize',15)
set(gca, 'XScale')
set(gca, 'YScale')
xlabel('Absorbed power (W)')
ylabel('{He(2^3S)} density (10^{18} m{^{-3}})')
ylim([0 1e19./scale]);
xlim([12.5 17.5])

set(gcf,'position',[100,100,600,450])

text(0.05,0.95,'(a)','Units','normalized','Color','k','FontSize',15)

% saveas(figure(1),'/home/he/Pictures/paper/2a_Nay19_nHeStar.jpg');
% saveas(figure(1),'/home/he/Pictures/paper/2a_Nay19_nHeStar.png');
% saveas(figure(1),'/home/he/Pictures/paper/2a_Nay19_nHeStar.eps', 'epsc');
% saveas(figure(1),'/home/he/Pictures/paper/2a_Nay19_nHeStar.pdf');

figure(2)
scale = 1e18;
yyaxis left

m1 = plot(stomus*t1,Hestar_t./scale,'s','Color','r','MarkerSize',8)
% set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
plot(stomus*time_sim,hestar_sim./scale,'r-.','LineWidth',2)
hold on
m2 = plot(stomus*t2,He2star_t./scale,'o','Color','b','MarkerSize',8)
% set(m2, 'markerfacecolor', get(m2, 'color'));
hold on
plot(stomus*time_sim,he2star_sim./scale,'b:','LineWidth',2)
hold on

xlabel('Time ({\mus})')
ylabel('Density (10^{18} m{^{-3}})')
set(gca,'FontSize',15)
set(gca, 'XScale')
set(gca, 'YScale')
xlim([-5 1e-4*stomus])
ylim([-1e17./scale 7e18./scale])
text(22, 4e18, 'He(2 ^3S)','color', 'r','FontSize',15)
text(50, 1.5e18, 'He_2^*','color', 'b','FontSize',15)
set(gca,'FontSize',15)

yyaxis right
set(gca, 'YScale')
plot(t_pow*stomus,pow,'--', 'Color', '[0 0.5 0]','Linewidth',2);
ylim([-0.5 16])
ylabel('Absorbed power (W)')
ax = gca;
ax.YAxis(1).Color = 'k';
ax.YAxis(2).Color = '[0 0.5 0]';

legend({'Meas. He(2^3S)(Peak)','Sim. He(2^3S)','Meas. He_2^*(Peak)','Sim. He_2^*','Absorbed power'},...
    'Location','NorthEast','FontSize',12)

set(gcf,'position',[100,100,600,450])

text(0.05,0.95,'(b)','Units','normalized','Color','k','FontSize',15)

% saveas(figure(2),'/home/he/Pictures/paper/2b_Nay19_nHeStar.jpg');
% saveas(figure(2),'/home/he/Pictures/paper/2b_Nay19_nHeStar.png');
% saveas(figure(2),'/home/he/Pictures/paper/2b_Nay19_nHeStar.eps', 'epsc');
% saveas(figure(2),'/home/he/Pictures/paper/2b_Nay19_nHeStar.pdf');




